@@ -104,6 +104,10 @@ __END__
 
 =encoding utf-8
 
+=for stopwords
+	CSV
+	YMIRLINK
+
 =head1 NAME
 
 Tripletail::CSV - CSV のパースと生成
@@ -188,7 +192,7 @@ CSV に問題があってパースできない場合は、C<next> メソッド
 
 =over 4
 
-Copyright 2006 YMIRLINK Inc. All Rights Reserved.
+Copyright 2006 YMIRLINK Inc.
 
 This framework is free software; you can redistribute it and/or modify it under the same terms as Perl itself
 
