@@ -140,6 +140,9 @@ __END__
 
 =encoding utf-8
 
+=for stopwords
+	YMIRLINK
+
 =head1 NAME
 
 Tripletail::CharConv - 内部クラス
@@ -156,7 +159,7 @@ L<Tripletail>
 
 =over 4
 
-Copyright 2006 YMIRLINK Inc. All Rights Reserved.
+Copyright 2006 YMIRLINK Inc.
 
 This framework is free software; you can redistribute it and/or modify it under the same terms as Perl itself
 
