@@ -44,6 +44,9 @@ __END__
 
 =encoding utf-8
 
+=for stopwords
+	YMIRLINK
+
 =head1 NAME
 
 Tripletail::Filter::HeaderOnly - ヘッダのみ出力
@@ -94,7 +97,7 @@ L<Tripletail::Filter>参照
 
 =over 4
 
-Copyright 2006 YMIRLINK Inc. All Rights Reserved.
+Copyright 2006 YMIRLINK Inc.
 
 This framework is free software; you can redistribute it and/or modify it under the same terms as Perl itself
 
